Coverage for /home/delusionalinsanity/bbrepos/matyan/src/matyan/tests/test_core.py: 100%

# Coverage for /home/delusionalinsanity/bbrepos/matyan/src/matyan/tests/test_core.py : 100%

## 0 statements 0 run 0 missing 0 excluded

Hot-keys on this page

r m x p toggle line displays

j k next/prev highlighted chunk

0 (zero) top of page

1 (one) first highlighted chunk

1 2 3 4 5 6 7 8 9 10 11 12 13 14 15 16 17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 32 33 34 35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 | # # -*- coding: utf-8 -*- # # import copy # import logging # import os # import unittest # # from ..utils import ( # create_config_file, # generate_changelog_cli, # generate_empty_tree, # get_branch_type, # get_logs, # json_changelog_cli, # prepare_changelog, # prepare_releases_changelog, # validate_between, # ) # # from .base import internet_available_only, log_info # # __author__ = 'Artur Barseghyan' # __copyright__ = '2019 Artur Barseghyan' # __license__ = 'GPL-2.0-only OR LGPL-2.0-or-later' # __all__ = ('TestCore',) # # LOGGER = logging.getLogger(__name__) # # # class TestCore(unittest.TestCase): # """Core matyan functionality tests.""" # # def setUp(self): # """Set up.""" # # TODO # # def tearDown(self): # """Tear down.""" # # TODO # # @internet_available_only # @log_info # def test_01_generate_changelog_command(self): # """Test generate changelog.""" # # TODO # # # if __name__ == '__main__': # unittest.main()